summaryrefslogtreecommitdiffstats
path: root/cui
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2013-09-23 07:19:08 +0100
committerCaolán McNamara <caolanm@redhat.com>2013-09-25 19:24:23 +0200
commit98de5b40c8a3fd4e57477b6d994e3b1472207f71 (patch)
tree567fdbbaecbddbfc19f28a08da5d1f6d5207748c /cui
parentfix TODO news:// is nonsense (diff)
downloadcore-98de5b40c8a3fd4e57477b6d994e3b1472207f71.tar.gz
core-98de5b40c8a3fd4e57477b6d994e3b1472207f71.zip
Related: fdo#38838 remove UniString::EqualsIgnoreCaseAscii
Change-Id: Ib5c3a2daa4a48bc286b14fa2cebb3306ea0012bc
Diffstat (limited to 'cui')
-rw-r--r--cui/source/dialogs/hldocntp.cxx8
-rw-r--r--cui/source/dialogs/hldoctp.cxx30
-rw-r--r--cui/source/dialogs/hlinettp.cxx16
-rw-r--r--cui/source/dialogs/hlmailtp.cxx4
-rw-r--r--cui/source/dialogs/hltpbase.cxx22
-rw-r--r--cui/source/dialogs/plfilter.cxx2
-rw-r--r--cui/source/inc/cfgutil.hxx1
-rw-r--r--cui/source/inc/cuifmsearch.hxx2
-rw-r--r--cui/source/inc/dbregister.hxx8
-rw-r--r--cui/source/inc/hldocntp.hxx2
-rw-r--r--cui/source/inc/hldoctp.hxx6
-rw-r--r--cui/source/inc/hlinettp.hxx2
-rw-r--r--cui/source/inc/hlmailtp.hxx2
-rw-r--r--cui/source/inc/hltpbase.hxx4
-rw-r--r--cui/source/inc/iconcdlg.hxx8
-rw-r--r--cui/source/inc/numfmt.hxx10
-rw-r--r--cui/source/options/cfgchart.hxx1
-rw-r--r--cui/source/options/connpoolsettings.hxx3
-rw-r--r--cui/source/tabpages/macroass.cxx4
19 files changed, 70 insertions, 65 deletions
diff --git a/cui/source/dialogs/hldocntp.cxx b/cui/source/dialogs/hldocntp.cxx
index 1a55181f6434..f554ef00afbb 100644
--- a/cui/source/dialogs/hldocntp.cxx
+++ b/cui/source/dialogs/hldocntp.cxx
@@ -218,16 +218,16 @@ void SvxHyperlinkNewDocTp::FillDocumentList ()
|*
|************************************************************************/
-void SvxHyperlinkNewDocTp::GetCurentItemData ( String& aStrURL, String& aStrName,
+void SvxHyperlinkNewDocTp::GetCurentItemData ( OUString& rStrURL, String& aStrName,
String& aStrIntName, String& aStrFrame,
SvxLinkInsertMode& eMode )
{
// get data from dialog-controls
- aStrURL = maCbbPath.GetText();
+ rStrURL = maCbbPath.GetText();
INetURLObject aURL;
- if ( ImplGetURLObject( aStrURL, maCbbPath.GetBaseURL(), aURL ) )
+ if ( ImplGetURLObject( rStrURL, maCbbPath.GetBaseURL(), aURL ) )
{
- aStrURL = aURL.GetMainURL( INetURLObject::NO_DECODE );
+ rStrURL = aURL.GetMainURL( INetURLObject::NO_DECODE );
}
GetDataFromCommonFields( aStrName, aStrIntName, aStrFrame, eMode );
diff --git a/cui/source/dialogs/hldoctp.cxx b/cui/source/dialogs/hldoctp.cxx
index d5092b9f4c60..a5ab744552c4 100644
--- a/cui/source/dialogs/hldoctp.cxx
+++ b/cui/source/dialogs/hldoctp.cxx
@@ -151,15 +151,15 @@ String SvxHyperlinkDocTp::GetCurrentURL ()
|*
|************************************************************************/
-void SvxHyperlinkDocTp::GetCurentItemData ( String& aStrURL, String& aStrName,
+void SvxHyperlinkDocTp::GetCurentItemData ( OUString& rStrURL, String& aStrName,
String& aStrIntName, String& aStrFrame,
SvxLinkInsertMode& eMode )
{
// get data from standard-fields
- aStrURL = GetCurrentURL();
+ rStrURL = GetCurrentURL();
- if( aStrURL.EqualsIgnoreCaseAscii( sFileScheme ) )
- aStrURL=aEmptyStr;
+ if( rStrURL.equalsIgnoreAsciiCase( sFileScheme ) )
+ rStrURL="";
GetDataFromCommonFields( aStrName, aStrIntName, aStrFrame, eMode );
}
@@ -198,8 +198,8 @@ IMPL_LINK_NOARG(SvxHyperlinkDocTp, ClickFileopenHdl_Impl)
::sfx2::FileDialogHelper aDlg(
com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE, 0,
GetParent() );
- String aOldURL( GetCurrentURL() );
- if( aOldURL.EqualsIgnoreCaseAscii( sFileScheme, 0, sizeof( sFileScheme ) - 1 ) )
+ OUString aOldURL( GetCurrentURL() );
+ if( aOldURL.startsWithIgnoreAsciiCase( sFileScheme ) )
{
aDlg.SetDisplayDirectory( aOldURL );
}
@@ -234,15 +234,15 @@ IMPL_LINK_NOARG(SvxHyperlinkDocTp, ClickFileopenHdl_Impl)
IMPL_LINK_NOARG(SvxHyperlinkDocTp, ClickTargetHdl_Impl)
{
if ( GetPathType ( maStrURL ) == Type_ExistsFile ||
- maStrURL == aEmptyStr ||
- maStrURL.EqualsIgnoreCaseAscii( sFileScheme ) ||
- maStrURL.SearchAscii( sHash ) == 0 )
+ maStrURL.isEmpty() ||
+ maStrURL.equalsIgnoreAsciiCase( sFileScheme ) ||
+ maStrURL.indexOf( sHash ) == 0 )
{
mpMarkWnd->SetError( LERR_NOERROR );
EnterWait();
- if ( maStrURL.EqualsIgnoreCaseAscii( sFileScheme ) )
+ if ( maStrURL.equalsIgnoreAsciiCase( sFileScheme ) )
mpMarkWnd->RefreshTree ( aEmptyStr );
else
mpMarkWnd->RefreshTree ( maStrURL );
@@ -284,12 +284,12 @@ IMPL_LINK_NOARG(SvxHyperlinkDocTp, ModifiedPathHdl_Impl)
IMPL_LINK_NOARG(SvxHyperlinkDocTp, TimeoutHdl_Impl)
{
if ( IsMarkWndVisible() && ( GetPathType( maStrURL )==Type_ExistsFile ||
- maStrURL == aEmptyStr ||
- maStrURL.EqualsIgnoreCaseAscii( sFileScheme ) ) )
+ maStrURL.isEmpty() ||
+ maStrURL.equalsIgnoreAsciiCase( sFileScheme ) ) )
{
EnterWait();
- if ( maStrURL.EqualsIgnoreCaseAscii( sFileScheme ) )
+ if ( maStrURL.equalsIgnoreAsciiCase( sFileScheme ) )
mpMarkWnd->RefreshTree ( aEmptyStr );
else
mpMarkWnd->RefreshTree ( maStrURL );
@@ -352,9 +352,9 @@ void SvxHyperlinkDocTp::SetMarkStr ( const String& aStrMark )
|*
|************************************************************************/
-SvxHyperlinkDocTp::EPathType SvxHyperlinkDocTp::GetPathType ( String& aStrPath )
+SvxHyperlinkDocTp::EPathType SvxHyperlinkDocTp::GetPathType ( const OUString& rStrPath )
{
- INetURLObject aURL( aStrPath, INET_PROT_FILE );
+ INetURLObject aURL( rStrPath, INET_PROT_FILE );
if( aURL.HasError() )
return Type_Invalid;
diff --git a/cui/source/dialogs/hlinettp.cxx b/cui/source/dialogs/hlinettp.cxx
index ab3786a083a7..bbd51e242a91 100644
--- a/cui/source/dialogs/hlinettp.cxx
+++ b/cui/source/dialogs/hlinettp.cxx
@@ -171,11 +171,11 @@ void SvxHyperlinkInternetTp::setFTPUser(const String& rUser, const String& rPass
|*
|************************************************************************/
-void SvxHyperlinkInternetTp::GetCurentItemData ( String& aStrURL, String& aStrName,
+void SvxHyperlinkInternetTp::GetCurentItemData ( OUString& rStrURL, String& aStrName,
String& aStrIntName, String& aStrFrame,
SvxLinkInsertMode& eMode )
{
- aStrURL = CreateAbsoluteURL();
+ rStrURL = CreateAbsoluteURL();
GetDataFromCommonFields( aStrName, aStrIntName, aStrFrame, eMode );
}
@@ -262,8 +262,8 @@ IMPL_LINK_NOARG(SvxHyperlinkInternetTp, TimeoutHdl_Impl)
IMPL_LINK_NOARG(SvxHyperlinkInternetTp, ModifiedLoginHdl_Impl)
{
- String aStrLogin ( maEdLogin.GetText() );
- if ( aStrLogin.EqualsIgnoreCaseAscii( sAnonymous ) )
+ OUString aStrLogin ( maEdLogin.GetText() );
+ if ( aStrLogin.equalsIgnoreAsciiCase( sAnonymous ) )
{
maCbAnonymous.Check();
ClickAnonymousHdl_Impl(NULL);
@@ -492,11 +492,11 @@ void SvxHyperlinkInternetTp::SetOnlineMode( sal_Bool /*bEnable*/ )
// State of target-button in subject to the current url-string
// ( Can't display any targets in an document, if there is no
// valid url to a document )
- String aStrCurrentTarget(comphelper::string::stripEnd(maCbbTarget.GetText(), ' '));
+ OUString aStrCurrentTarget(comphelper::string::stripEnd(maCbbTarget.GetText(), ' '));
- if( aStrCurrentTarget == aEmptyStr ||
- aStrCurrentTarget.EqualsIgnoreCaseAscii( sHTTPScheme ) ||
- aStrCurrentTarget.EqualsIgnoreCaseAscii( sHTTPSScheme ) )
+ if( aStrCurrentTarget.isEmpty() ||
+ aStrCurrentTarget.equalsIgnoreAsciiCase( sHTTPScheme ) ||
+ aStrCurrentTarget.equalsIgnoreAsciiCase( sHTTPSScheme ) )
maBtTarget.Enable( sal_False );
else
maBtTarget.Enable( sal_True );
diff --git a/cui/source/dialogs/hlmailtp.cxx b/cui/source/dialogs/hlmailtp.cxx
index d799c6ce2db5..ef36989d5679 100644
--- a/cui/source/dialogs/hlmailtp.cxx
+++ b/cui/source/dialogs/hlmailtp.cxx
@@ -136,11 +136,11 @@ void SvxHyperlinkMailTp::FillDlgFields ( String& aStrURL )
|*
|************************************************************************/
-void SvxHyperlinkMailTp::GetCurentItemData ( String& aStrURL, String& aStrName,
+void SvxHyperlinkMailTp::GetCurentItemData ( OUString& rStrURL, String& aStrName,
String& aStrIntName, String& aStrFrame,
SvxLinkInsertMode& eMode )
{
- aStrURL = CreateAbsoluteURL();
+ rStrURL = CreateAbsoluteURL();
GetDataFromCommonFields( aStrName, aStrIntName, aStrFrame, eMode );
}
diff --git a/cui/source/dialogs/plfilter.cxx b/cui/source/dialogs/plfilter.cxx
index 427c42b5ddb9..66a68a1cf0d8 100644
--- a/cui/source/dialogs/plfilter.cxx
+++ b/cui/source/dialogs/plfilter.cxx
@@ -29,6 +29,8 @@
#include <com/sun/star/plugin/PluginManager.hpp>
#include <com/sun/star/plugin/XPluginManager.hpp>
+#include <tools/string.hxx>
+
using namespace std;
using namespace com::sun::star::uno;
using namespace com::sun::star::lang;
diff --git a/cui/source/inc/cfgutil.hxx b/cui/source/inc/cfgutil.hxx
index 609ef3440d3a..c7a29c38ee23 100644
--- a/cui/source/inc/cfgutil.hxx
+++ b/cui/source/inc/cfgutil.hxx
@@ -22,7 +22,6 @@
#include <vector>
#include <boost/ptr_container/ptr_vector.hpp>
#include <rtl/ustring.hxx>
-#include <tools/string.hxx>
#include <com/sun/star/frame/XModel.hpp>
#include <com/sun/star/frame/XFrame.hpp>
diff --git a/cui/source/inc/cuifmsearch.hxx b/cui/source/inc/cuifmsearch.hxx
index 61c7386ae85c..a04f5ed860d8 100644
--- a/cui/source/inc/cuifmsearch.hxx
+++ b/cui/source/inc/cuifmsearch.hxx
@@ -32,7 +32,7 @@
#include <tools/link.hxx>
#include <comphelper/uno3.hxx>
#include <comphelper/stl_types.hxx>
-#include <tools/string.hxx>
+#include <rtl/ustring.hxx>
namespace svxform {
class FmSearchConfigItem;
diff --git a/cui/source/inc/dbregister.hxx b/cui/source/inc/dbregister.hxx
index 63e9b76518ac..9a5c7bf532c1 100644
--- a/cui/source/inc/dbregister.hxx
+++ b/cui/source/inc/dbregister.hxx
@@ -20,13 +20,13 @@
#ifndef SVX_DBREGISTER_HXX
#define SVX_DBREGISTER_HXX
-#include "optpath.hxx"
-#include <tools/string.hxx>
#include <comphelper/stl_types.hxx>
-#include <svl/poolitem.hxx>
-#include "ControlFocusHelper.hxx"
+#include <rtl/ustring.hxx>
#include <sfx2/basedlgs.hxx>
+#include <svl/poolitem.hxx>
#include <svtools/simptabl.hxx>
+#include "optpath.hxx"
+#include "ControlFocusHelper.hxx"
class SvTreeListEntry;
namespace svx
diff --git a/cui/source/inc/hldocntp.hxx b/cui/source/inc/hldocntp.hxx
index 0f5832a59453..9ae773810a5b 100644
--- a/cui/source/inc/hldocntp.hxx
+++ b/cui/source/inc/hldocntp.hxx
@@ -48,7 +48,7 @@ private:
protected:
void FillDlgFields ( String& aStrURL );
- void GetCurentItemData ( String& aStrURL, String& aStrName,
+ void GetCurentItemData ( OUString& rStrURL, String& aStrName,
String& aStrIntName, String& aStrFrame,
SvxLinkInsertMode& eMode );
diff --git a/cui/source/inc/hldoctp.hxx b/cui/source/inc/hldoctp.hxx
index 786a422f94b5..0ef62b25e6e2 100644
--- a/cui/source/inc/hldoctp.hxx
+++ b/cui/source/inc/hldoctp.hxx
@@ -42,7 +42,7 @@ private:
FixedText maFtFullURL;
ImageButton maBtBrowse;
- String maStrURL;
+ OUString maStrURL;
sal_Bool mbMarkWndOpen;
@@ -59,11 +59,11 @@ private:
enum EPathType { Type_Unknown, Type_Invalid,
Type_ExistsFile, Type_File,
Type_ExistsDir, Type_Dir };
- EPathType GetPathType ( String& aStrPath );
+ EPathType GetPathType ( const OUString& rStrPath );
protected:
void FillDlgFields ( String& aStrURL );
- void GetCurentItemData ( String& aStrURL, String& aStrName,
+ void GetCurentItemData ( OUString& rStrURL, String& aStrName,
String& aStrIntName, String& aStrFrame,
SvxLinkInsertMode& eMode );
virtual sal_Bool ShouldOpenMarkWnd () {return mbMarkWndOpen;}
diff --git a/cui/source/inc/hlinettp.hxx b/cui/source/inc/hlinettp.hxx
index c79ead82657c..419465d455f7 100644
--- a/cui/source/inc/hlinettp.hxx
+++ b/cui/source/inc/hlinettp.hxx
@@ -74,7 +74,7 @@ private:
protected:
virtual void FillDlgFields ( String& aStrURL );
- virtual void GetCurentItemData ( String& aStrURL, String& aStrName,
+ virtual void GetCurentItemData ( OUString& rStrURL, String& aStrName,
String& aStrIntName, String& aStrFrame,
SvxLinkInsertMode& eMode );
virtual sal_Bool ShouldOpenMarkWnd () {return ( mbMarkWndOpen && maRbtLinktypInternet.IsChecked() );}
diff --git a/cui/source/inc/hlmailtp.hxx b/cui/source/inc/hlmailtp.hxx
index 9fdb4a5b22ab..0cbc6b2acbaf 100644
--- a/cui/source/inc/hlmailtp.hxx
+++ b/cui/source/inc/hlmailtp.hxx
@@ -52,7 +52,7 @@ private:
protected:
virtual void FillDlgFields ( String& aStrURL );
- virtual void GetCurentItemData ( String& aStrURL, String& aStrName,
+ virtual void GetCurentItemData ( OUString& rStrURL, String& aStrName,
String& aStrIntName, String& aStrFrame,
SvxLinkInsertMode& eMode );
diff --git a/cui/source/inc/hltpbase.hxx b/cui/source/inc/hltpbase.hxx
index 8e80f17d2d01..945c104cce29 100644
--- a/cui/source/inc/hltpbase.hxx
+++ b/cui/source/inc/hltpbase.hxx
@@ -105,7 +105,7 @@ protected:
void InitStdControls ();
virtual void FillStandardDlgFields ( SvxHyperlinkItem* pHyperlinkItem );
virtual void FillDlgFields ( String& aStrURL ) = 0;
- virtual void GetCurentItemData ( String& aStrURL, String& aStrName,
+ virtual void GetCurentItemData ( OUString& rStrURL, String& aStrName,
String& aStrIntName, String& aStrFrame,
SvxLinkInsertMode& eMode ) = 0;
virtual String CreateUiNameFromURL( const String& aStrURL );
@@ -118,7 +118,7 @@ protected:
String aEmptyStr;
- static String GetSchemeFromURL( String aStrURL );
+ static OUString GetSchemeFromURL( const OUString& rStrURL );
inline void DisableClose( sal_Bool _bDisable ) { mbIsCloseDisabled = _bDisable; }
diff --git a/cui/source/inc/iconcdlg.hxx b/cui/source/inc/iconcdlg.hxx
index 73e01e5ad2c1..84dee6977a6a 100644
--- a/cui/source/inc/iconcdlg.hxx
+++ b/cui/source/inc/iconcdlg.hxx
@@ -19,15 +19,15 @@
#ifndef _ICCDLG_HXX
#define _ICCDLG_HXX
+#include <rtl/ustring.hxx>
+#include <svl/itempool.hxx>
+#include <svl/itemset.hxx>
+#include <svtools/ivctrl.hxx>
#include <vcl/tabpage.hxx>
#include <vcl/msgbox.hxx>
#include <vcl/dialog.hxx>
#include <vcl/button.hxx>
#include <vcl/image.hxx>
-#include <svtools/ivctrl.hxx>
-#include <svl/itempool.hxx>
-#include <svl/itemset.hxx>
-#include <tools/string.hxx>
#include <vector>
#define CTRLS_OFFSET 3
diff --git a/cui/source/inc/numfmt.hxx b/cui/source/inc/numfmt.hxx
index 12761d031cf5..57dd1d72f150 100644
--- a/cui/source/inc/numfmt.hxx
+++ b/cui/source/inc/numfmt.hxx
@@ -21,17 +21,17 @@
//------------------------------------------------------------------------
-#include <vcl/window.hxx>
-#include <tools/color.hxx>
-#include <tools/string.hxx>
+#include <rtl/ustring.hxx>
#include <sfx2/tabdlg.hxx>
+#include <svx/langbox.hxx>
+#include <svx/fontlb.hxx>
+#include <tools/color.hxx>
#include <vcl/fixed.hxx>
#include <vcl/lstbox.hxx>
#include <vcl/edit.hxx>
#include <vcl/toolbox.hxx>
#include <vcl/field.hxx>
-#include <svx/langbox.hxx>
-#include <svx/fontlb.hxx>
+#include <vcl/window.hxx>
//------------------------------------------------------------------------
diff --git a/cui/source/options/cfgchart.hxx b/cui/source/options/cfgchart.hxx
index a8eeed37bd50..03f7a78a1c95 100644
--- a/cui/source/options/cfgchart.hxx
+++ b/cui/source/options/cfgchart.hxx
@@ -22,6 +22,7 @@
// header for TYPEINFO
#include <tools/rtti.hxx>
+#include <tools/string.hxx>
// header for ConfigItem
#include <unotools/configitem.hxx>
// header for SfxPoolItem
diff --git a/cui/source/options/connpoolsettings.hxx b/cui/source/options/connpoolsettings.hxx
index 4bd0d32a256e..a93f6aacf509 100644
--- a/cui/source/options/connpoolsettings.hxx
+++ b/cui/source/options/connpoolsettings.hxx
@@ -20,9 +20,10 @@
#ifndef _OFFAPP_CONNPOOLSETTINGS_HXX_
#define _OFFAPP_CONNPOOLSETTINGS_HXX_
-#include <tools/string.hxx>
#include <comphelper/stl_types.hxx>
+#include <rtl/ustring.hxx>
#include <svl/poolitem.hxx>
+#include <tools/string.hxx>
//........................................................................
namespace offapp
diff --git a/cui/source/tabpages/macroass.cxx b/cui/source/tabpages/macroass.cxx
index 084a17198290..fede730be3c3 100644
--- a/cui/source/tabpages/macroass.cxx
+++ b/cui/source/tabpages/macroass.cxx
@@ -150,8 +150,8 @@ void _SfxMacroTabPage::EnableButtons()
String sEventMacro;
sEventMacro = ((SvLBoxString*)pE->GetItem( LB_MACROS_ITEMPOS ))->GetText();
- String sScriptURI = mpImpl->pMacroLB->GetSelectedScriptURI();
- mpImpl->pAssignPB->Enable( !mpImpl->bReadOnly && !sScriptURI.EqualsIgnoreCaseAscii( sEventMacro ) );
+ OUString sScriptURI = mpImpl->pMacroLB->GetSelectedScriptURI();
+ mpImpl->pAssignPB->Enable( !mpImpl->bReadOnly && !sScriptURI.equalsIgnoreAsciiCase( sEventMacro ) );
}
else
mpImpl->pAssignPB->Enable( sal_False );
diff --git a/cui/source/dialogs/hltpbase.cxx b/cui/source/dialogs/hltpbase.cxx
index 2ede80c294dc..762a58110fca 100644
--- a/cui/source/dialogs/hltpbase.cxx
+++ b/cui/source/dialogs/hltpbase.cxx
@@ -414,12 +414,12 @@ SvxMacroTableDtor* SvxHyperlinkTabPageBase::GetMacroTable()
return ( (SvxMacroTableDtor*)pHyperlinkItem->GetMacroTbl() );
}
-// try to detect the current protocol that is used in aStrURL
-String SvxHyperlinkTabPageBase::GetSchemeFromURL( String aStrURL )
+// try to detect the current protocol that is used in rStrURL
+OUString SvxHyperlinkTabPageBase::GetSchemeFromURL( const OUString& rStrURL )
{
String aStrScheme;
- INetURLObject aURL( aStrURL );
+ INetURLObject aURL( rStrURL );
INetProtocol aProtocol = aURL.GetProtocol();
// #77696#
@@ -427,23 +427,23 @@ String SvxHyperlinkTabPageBase::GetSchemeFromURL( String aStrURL )
// to detect if an Url is valid or not :-(
if ( aProtocol == INET_PROT_NOT_VALID )
{
- if ( aStrURL.EqualsIgnoreCaseAscii( INET_HTTP_SCHEME, 0, 7 ) )
+ if ( rStrURL.startsWithIgnoreAsciiCase( INET_HTTP_SCHEME ) )
{
aStrScheme = OUString( INET_HTTP_SCHEME );
}
- else if ( aStrURL.EqualsIgnoreCaseAscii( INET_HTTPS_SCHEME, 0, 8 ) )
+ else if ( rStrURL.startsWithIgnoreAsciiCase( INET_HTTPS_SCHEME ) )
{
aStrScheme = OUString( INET_HTTPS_SCHEME );
}
- else if ( aStrURL.EqualsIgnoreCaseAscii( INET_FTP_SCHEME, 0, 6 ) )
+ else if ( rStrURL.startsWithIgnoreAsciiCase( INET_FTP_SCHEME ) )
{
aStrScheme = OUString( INET_FTP_SCHEME );
}
- else if ( aStrURL.EqualsIgnoreCaseAscii( INET_MAILTO_SCHEME, 0, 7 ) )
+ else if ( rStrURL.startsWithIgnoreAsciiCase( INET_MAILTO_SCHEME ) )
{
aStrScheme = OUString( INET_MAILTO_SCHEME );
}
- else if ( aStrURL.EqualsIgnoreCaseAscii( INET_NEWS_SCHEME, 0, 5 ) )
+ else if ( rStrURL.startsWithIgnoreAsciiCase( INET_NEWS_SCHEME ) )
{
aStrScheme = OUString( INET_NEWS_SCHEME );
}
@@ -492,7 +492,8 @@ void SvxHyperlinkTabPageBase::Reset( const SfxItemSet& rItemSet)
// Fill output-ItemSet
sal_Bool SvxHyperlinkTabPageBase::FillItemSet( SfxItemSet& rOut)
{
- String aStrURL, aStrName, aStrIntName, aStrFrame;
+ OUString aStrURL;
+ String aStrName, aStrIntName, aStrFrame;
SvxLinkInsertMode eMode;
GetCurentItemData ( aStrURL, aStrName, aStrIntName, aStrFrame, eMode);
@@ -563,7 +564,8 @@ int SvxHyperlinkTabPageBase::DeactivatePage( SfxItemSet* _pSet)
HideMarkWnd ();
// retrieve data of dialog
- String aStrURL, aStrName, aStrIntName, aStrFrame;
+ OUString aStrURL;
+ String aStrName, aStrIntName, aStrFrame;
SvxLinkInsertMode eMode;
GetCurentItemData ( aStrURL, aStrName, aStrIntName, aStrFrame, eMode);